@@ -12,22 +12,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from selenium import webdriver
+from typing import TYPE_CHECKING, Any
 
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
+if TYPE_CHECKING:
+    from appium.webdriver.webdriver import WebDriver
 
-class Common(webdriver.Remote):
 
-    def end_test_coverage(self, intent, path):
+class Common(CanExecuteCommands):
+    def end_test_coverage(self, intent: str, path: str) -> Any:  # TODO Check return type
         """Ends the coverage collection and pull the coverage.ec file from the device.
 
         Android only.
         See https://github.com/appium/appium/blob/master/docs/en/writing-running-appium/android/android-coverage.md
 
         Args:
-            intent (str): description of operation to be performed
-            path (str): path to coverage.ec file to be pulled from the device
+            intent: description of operation to be performed
+            path: path to coverage.ec file to be pulled from the device
 
         Returns:
             TODO
@@ -38,25 +41,32 @@ class Common(webdriver.Remote):
         }
         return self.execute(Command.END_TEST_COVERAGE, data)['value']
 
-    def open_notifications(self):
+    def open_notifications(self) -> 'WebDriver':
         """Open notification shade in Android (API Level 18 and above)
 
         Returns:
-            `appium.webdriver.webdriver.WebDriver`
+            Union['WebDriver', 'Common']: Self instance
         """
         self.execute(Command.OPEN_NOTIFICATIONS, {})
-        return self
+        return self  # type: ignore
 
     @property
-    def current_package(self):
-        """Retrieves the current package running on the device.
-        """
+    def current_package(self) -> str:
+        """Retrieves the current package running on the device."""
         return self.execute(Command.GET_CURRENT_PACKAGE)['value']
 
-    def _addCommands(self):
-        self.command_executor._commands[Command.GET_CURRENT_PACKAGE] = \
-            ('GET', '/session/$sessionId/appium/device/current_package')
-        self.command_executor._commands[Command.END_TEST_COVERAGE] = \
-            ('POST', '/session/$sessionId/appium/app/end_test_coverage')
-        self.command_executor._commands[Command.OPEN_NOTIFICATIONS] = \
-            ('POST', '/session/$sessionId/appium/device/open_notifications')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_CURRENT_PACKAGE] = (
+            'GET',
+            '/session/$sessionId/appium/device/current_package',
+        )
+        commands[Command.END_TEST_COVERAGE] = (
+            'POST',
+            '/session/$sessionId/appium/app/end_test_coverage',
+        )
+        commands[Command.OPEN_NOTIFICATIONS] = (
+            'POST',
+            '/session/$sessionId/appium/device/open_notifications',
+        )
