@@ -12,37 +12,39 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from selenium import webdriver
+from typing import Dict, Union
 
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
 
-class SystemBars(webdriver.Remote):
-
-    def get_system_bars(self):
+class SystemBars(CanExecuteCommands):
+    def get_system_bars(self) -> Dict[str, Dict[str, Union[int, bool]]]:
         """Retrieve visibility and bounds information of the status and navigation bars.
 
         Android only.
 
         Returns:
             A dictionary whose keys are
-             - statusBar
-               - visible
-               - x
-               - y
-               - width
-               - height
-             - navigationBar
-               - visible
-               - x
-               - y
-               - width
-               - height
+               - statusBar
+                   - visible
+                   - x
+                   - y
+                   - width
+                   - height
+               - navigationBar
+                   - visible
+                   - x
+                   - y
+                   - width
+                   - height
         """
         return self.execute(Command.GET_SYSTEM_BARS)['value']
 
-    # pylint: disable=protected-access
-
-    def _addCommands(self):
-        self.command_executor._commands[Command.GET_SYSTEM_BARS] = \
-            ('GET', '/session/$sessionId/appium/device/system_bars')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_SYSTEM_BARS] = (
+            'GET',
+            '/session/$sessionId/appium/device/system_bars',
+        )
