@@ -12,20 +12,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, Any, Dict, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict
 
-from selenium import webdriver
+from appium.protocols.webdriver.can_execute_scripts import CanExecuteScripts
 
 if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
     from appium.webdriver.webdriver import WebDriver
 
-T = TypeVar('T', bound=Union['WebDriver', 'ExecuteMobileCommand'])
 
-
-class ExecuteMobileCommand(webdriver.Remote):
-
-    def press_button(self: T, button_name: str) -> T:
+class ExecuteMobileCommand(CanExecuteScripts):
+    def press_button(self, button_name: str) -> 'WebDriver':
         """Sends a physical button name to the device to simulate the user pressing.
 
         iOS only.
@@ -39,14 +35,12 @@ class ExecuteMobileCommand(webdriver.Remote):
             Union['WebDriver', 'ExecuteMobileCommand']: Self instance
 
         """
-        data = {
-            'name': button_name
-        }
+        data = {'name': button_name}
         self.execute_script('mobile: pressButton', data)
-        return self
+        return self  # type: ignore
 
     @property
-    def battery_info(self: T) -> Dict[str, Any]:
+    def battery_info(self) -> Dict[str, Any]:
         """Retrieves battery information for the device under test.
 
         Returns:
